==> vmp-0.3.3.tar.xz: vmp-0.3.3/framework/src/event/lib/lib.h <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
 * Date last update: 21/04/2020
 */

#ifndef VAMPIRIA_EVENT_LIB_H

#define VAMPIRIA_EVENT_LIB_H 1

namespace vampiria { namespace event {

class Cell;
class Manager;
class UI;

typedef void (*EVTCB)(event::Cell *cell);/*!< Simplex type callback*/
typedef void (*EVTCBSTR)(event::Cell *cell,vmp::str data); /*!< Event string type callback*/

//!Empty EVTCB callback
void empty_ev(event::Cell *cell);

//!Empty EVTCBSTR callback
void empty_str_ev(event::Cell *cell,vmp::str data);

//!Base class event
class Event
{
    public:
       //!A Constructor
       Event();

       //!A destructor
       ~Event();

       vmp_bool active_;/*!event is active?*/
       vmp_int priority_; /*!<priority of the event execution*/

       void set_priority(vmp_int priority=0);

       vmp_int fd_;/*< Filedescriptor associated*/

       event::Cell *cell_;/*<Cell associated*/

       //!Create a new event base
       /*!
           @param  ui user interface (see Class UI)
           @param  fd filedescriptor associated with the event
           @param  read  function performed in the loop
           @param  close function performed at the end of the event
           @return the new cell associated with the event
       */
       event::Cell *evt_new(event::UI *ui,vmp_int fd,event::EVTCB read,event::EVTCB close);
       
       //!Active o deactive event
       /*!
           @param active true or false
           @sa active
       */
       void evt_active(vmp_bool active);

       //! Close event
       void evt_close();

       //! Free event
       void evt_free();
};

//!Event Pipe base event.
class EventPipe:public event::Event
{
    public:
       //!A Constructor
       EventPipe();

       //!A Destructor
       ~EventPipe();

       vmp_int wfd_;/*!<Write filedescriptor*/

       //!Create pipe event
       /*!
            @param  ui user interface (see Class UI)
            @param  read  function performed in the loop
            @param  close function performed at the end of the event
            @return the new cell associated with the event
       */
       event::Cell *evt_pipe_new(event::UI *ui,event::EVTCB read,event::EVTCB close);
       
       //!Close write filedescriptor
       void evt_pipe_closew();
       
       //! Close pipe event
       void evt_pipe_close();

       //! Free pipe event
       void evt_pipe_free();
};

}}

#endif

==> vmp-0.5.1.tar.xz: vmp-0.5.1/framework/src/event/lib/lib.h <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
 * Date last update: 14/01/2023
 */

#ifndef VAMPIRIA_EVENT_LIB_H

#define VAMPIRIA_EVENT_LIB_H 1

namespace vampiria { namespace event {

class Cell;
class Manager;
class UI;

typedef void (*EVTCB)(event::Cell *cell);/*!< Simplex type callback*/
typedef void (*EVTCBBUF)(event::Cell *cell,vmp::Buf *buf);/*<!Event Buffer type callback*/
typedef void (*EVTCBSTR)(event::Cell *cell,vmp::str data); /*!< Event string type callback*/

//!Empty EVTCB callback
void empty_ev(event::Cell *cell);

//!Empty EVTCBBUF callback
void empty_buf_ev(event::Cell *cell,vmp::Buf *buf);

//!Empty EVTCBSTR callback
void empty_str_ev(event::Cell *cell,vmp::str data);

//!Base class event
class Event
{
    public:
       //!A Constructor
       Event();

       //!A destructor
       ~Event();

       vmp_bool active_;/*!event is active?*/
       vmp_int priority_; /*!<priority of the event execution*/

       void set_priority(vmp_int priority=0);

       vmp_int fd_;/*< Filedescriptor associated*/

       event::Cell *cell_;/*<Cell associated*/

       //!Create a new event base
       /*!
           @param  ui user interface (see Class UI)
           @param  fd filedescriptor associated with the event
           @param  read  function performed in the loop
           @param  close function performed at the end of the event
           @return the new cell associated with the event
       */
       event::Cell *evt_new(event::UI *ui,vmp_int fd,event::EVTCB read,event::EVTCB close);
       
       //!Active o deactive event
       /*!
           @param active true or false
           @sa active
       */
       void evt_active(vmp_bool active);

       //! Close event
       void evt_close();

       //! Free event
       void evt_free();
};

//!Event Pipe base event.
class EventPipe:public event::Event
{
    public:
       //!A Constructor
       EventPipe();

       //!A Destructor
       ~EventPipe();

       vmp_int wfd_;/*!<Write filedescriptor*/

       //!Create pipe event
       /*!
            @param  ui user interface (see Class UI)
            @param  read  function performed in the loop
            @param  close function performed at the end of the event
            @return the new cell associated with the event
       */
       event::Cell *evt_pipe_new(event::UI *ui,event::EVTCB read,event::EVTCB close);
       
       //!Close write filedescriptor
       void evt_pipe_closew();
       
       //! Close pipe event
       void evt_pipe_close();

       //! Free pipe event
       void evt_pipe_free();
};

}}

#endif
